@@ -49,7 +49,7 @@ def _isb_connection_info() -> dict:
 
 
 @contextmanager
-def recipe_run_failure_producer_factory():
+def recipe_run_failure_message_producer_factory():
     try:
         with DurableBlockingProducerWrapper(
             producer_queue_bindings=RecipeRunFailureMessage.binding(),
@@ -78,8 +78,11 @@ def chat_ops_notification(
     workflow_name: str,
     workflow_version: str,
     task_name: str,
-    producer_factory=recipe_run_failure_producer_factory,
+    producer_factory=recipe_run_failure_message_producer_factory,
 ):
+    """
+    Publish message with information regarding a task failure for publication to a chat service
+    """
     dag_run_id = parse_dag_run_id_from_context(context)
     log_url = parse_log_url_from_context(context)
     message = RecipeRunFailureMessage(
