@@ -1,6 +1,7 @@
 """Utilities for the build pipeline"""
 import importlib
 from pathlib import Path
+from shutil import rmtree
 from types import ModuleType
 from typing import Any
 from typing import List
@@ -15,17 +16,23 @@ from dkist_processing_core import Workflow
 __all__ = ["validate_workflows", "export"]
 
 
-def validate_workflows(
-    workflow_package: ModuleType, export_path: Optional[Union[str, Path]] = None
-) -> None:
+def validate_workflows(workflow_package: ModuleType, export_path: Optional[Path] = None) -> None:
     """
     Validates that workflow engine (airflow) objects are acyclic and that
     exported workflows compile.
     """
-    dags = _extract_airflow_dags_from_package(workflow_package)
-    _validate_dags(dags)
+    # configure export path.  Clean up after if export path not provided
+    rm_export_path_after_test = not bool(export_path)
+    if export_path is None:
+        export_path = Path("export/")
     workflows = _extract_workflows_from_package(workflow_package)
-    _validate_workflows(workflows, export_path)
+    try:
+        _validate_workflows(workflows, export_path)
+    finally:
+        if rm_export_path_after_test:
+            rmtree(export_path)
+    dags = [w.load() for w in workflows]
+    _validate_dags(dags)
 
 
 def export(workflow_package: ModuleType, export_path: Optional[Union[str, Path]] = None) -> None:
@@ -35,10 +42,6 @@ def export(workflow_package: ModuleType, export_path: Optional[Union[str, Path]]
     [w.export(export_path) for w in _extract_workflows_from_package(workflow_package)]
 
 
-def _extract_airflow_dags_from_package(workflow_package: ModuleType) -> List[DAG]:
-    return _extract_objects_from_package_by_type(workflow_package, DAG)
-
-
 def _extract_workflows_from_package(workflow_package: ModuleType) -> List[Workflow]:
     return _extract_objects_from_package_by_type(workflow_package, Workflow)
 
@@ -58,6 +61,9 @@ def _parse_unprotected_modules_names_from_package(package: ModuleType) -> List[s
 
 
 def _validate_dags(dags: List[DAG]):
+    """
+    Validate dags by ensuring they can be traversed without cycles and are syntactically correct
+    """
     for d in dags:
         try:
             d.topological_sort()
@@ -65,7 +71,10 @@ def _validate_dags(dags: List[DAG]):
             raise SyntaxError(f"DAG {d.dag_id} malformed.  Parsing resulted in error: {e=}") from e
 
 
-def _validate_workflows(workflows: List[Workflow], export_path: Optional[Union[str, Path]] = None):
+def _validate_workflows(workflows: List[Workflow], export_path: Path):
+    """
+    Validate workflows by ensuring their exported version compiles as python
+    """
     for w in workflows:
         try:
             workflow_py = w.export(export_path)
